@@ -6,3 +6,7 @@ from qfin.simulations import MonteCarloBinaryCall
 from qfin.simulations import MonteCarloBinaryPut
 from qfin.simulations import MonteCarloCall
 from qfin.simulations import MonteCarloPut
+from qfin.simulations import MonteCarloBarrierCall
+from qfin.simulations import MonteCarloBarrierPut
+from qfin.simulations import MonteCarloAsianCall
+from qfin.simulations import MonteCarloAsianPut
